:description: How to Manage Multitenancy Projects in Django and Maintain Sanity (spoiler, it is impossible).

Managing Multi-tenancy in Django
================================

.. warning::

    Work in progress. To receive updates `subscribe to this discussion <https://github.com/Tobi-De/falco/discussions/39>`_ or
    follow me on `x <https://twitter.com/tobidegnon>`_ or `mastodon <https://fosstodon.org/@tobide>`_.
